==> xmonad-extras-0.17.2-73-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-63rpQCWv2tL7Dx6vomTufz
key:                  xmonad-extras-0.17.2-63rpQCWv2tL7Dx6vomTufz
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  beb85e21144d2fd315c99f90d0ff6e58
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-63rpQCWv2tL7Dx6vomTufz
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.1-28XXic3AkPz2f0zaQA15wb
    hint-0.9.0.8-DnzjRtsOx6QHMqOGXnuIOo
    libmpd-0.10.0.1-4zpDmnzYjCKIrB4YiCQMkj mtl-2.2.2
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-LPBluBhDHdoEGm3DuH5vDt
    xmonad-contrib-0.18.1-8zUi1xFVASs2iF7gSFbrRq

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-extras-0.17.2-75-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-cWwLs31LjI1oxIeYHd3fC
key:                  xmonad-extras-0.17.2-cWwLs31LjI1oxIeYHd3fC
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  58a42ff40fb49ddc01d776701f4134ff
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-cWwLs31LjI1oxIeYHd3fC
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.1-Gki65xEKWvLCJfEVaekkWm
    hint-0.9.0.8-DnzjRtsOx6QHMqOGXnuIOo
    libmpd-0.10.0.1-4zpDmnzYjCKIrB4YiCQMkj mtl-2.2.2
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-EfsSBVHH1nO1gLQ8Lba3X1
    xmonad-contrib-0.18.1-45oB3fgFVoV6dUPP87UaUZ

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
